# Quickstart

```{note}
See the [Installation instructions](#installation) first if you have not yet installed Nipoppy.
```

## Initializing a new dataset

An Nipoppy directory tree can be generated by running [`nipoppy init`](../cli_reference/init) in an empty directory. You can also specify the directory path directly (Nipoppy will create it if it doesn't exist):
```{code-block} console
$ nipoppy init --dataset <DATASET_ROOT>
```

```{warning}
Initializing inside a non-empty directory will result in an error.
```

The newly created directory tree follows the Nipoppy specification. Other Nipoppy commands expect all these directories to exist -- they will throw an error if that is not the case.

```{tip}
Each subdirectory contains a `README.md` file that briefly describes the purpose of the subdirectory and the type of data that it should contain.
```

## Creating/modifying required files

Nipoppy requires two user-provided files in each dataset: a **{term}`JSON` configuration file** and a **tabular manifest file**. Commands will result in errors if either of these files does not exist or are invalid.

```{note}
The [`nipoppy init`](../cli_reference/init) command copies examples of these files to the expected paths within a new dataset, but you will most likely have to modify/overwrite them.
```

(customizing-config)=
### Customizing the global configuration file

The global configuration file at {{fpath_config}} contains high-level essential configurations for running Nipoppy commands. It starts out like this:
```{literalinclude} ../../../nipoppy/data/examples/sample_global_config.json
---
linenos: True
language: json
---
```

By default, this file does not contain any pipeline-specific information, since the dataset does not have any pipelines installed yet. Still, there are fields that may need to be modified depending on your setup:
- If you are on a system that still uses Singularity (which has been renamed to Apptainer), you need to change `CONTAINER_CONFIG` -> `COMMAND` to `"singularity"` instead of `"apptainer"`
- If your group uses a shared directory for storing container image files, you can replace `"[[NIPOPPY_DPATH_ROOT]]/containers"` by the full path to that shared directory.
    - Alternatively, you can create a symlink from {{dpath_containers}} to that directory (then this line in the configuration can be deleted).

As pipelines are installed into the dataset, this file may need to be modified to set pipeline-specific variables.


### Generating the manifest file

The manifest file at {{fpath_manifest}} contains *ground truth* information about the participants and visits/sessions available for a dataset.

There must be only **one row** per unique participant/visit combination.

The example manifest looks like this:
```{csv-table}
---
file: ../../../nipoppy/data/examples/sample_manifest.tsv
header-rows: 1
delim: tab
---
```

````{admonition} Raw content of the example manifest file
---
class: dropdown
---
```{literalinclude} ../../../nipoppy/data/examples/sample_manifest.tsv
---
linenos: True
---
```
````

It is extremely unlikely that this manifest file works for your dataset, so you will have to generate one yourself. We recommend writing a script, for the purpose of reproducibility and easy updates if the more data is added to the dataset.


% TODO point to example script for generating a manifest

```{tip}
See the {ref}`schema reference <manifest-schema>` for more information about each column.
```

## Next steps

```{note}

The rest of this documentation is still work in progress. If the information you are looking for is not available in the user guide, refer to the [commands](../cli_reference/index) associated with the data organization or processing step(s) you wish to perform.

![Nipoppy protocol](../_static/img/nipoppy_protocol.jpg)
```

Once the Nipoppy directory tree for a study is created, the next steps are typically to [populate it with raw data](../how_to_guides/user_guide/populating.md), [move and organize raw imaging data (typically DICOMs) into a regular structure](../how_to_guides/user_guide/organizing_imaging.md), then [convert the data to BIDS](../how_to_guides/user_guide/bids_conversion.md). However, depending on the type of raw data you have, your workflow might be a little different. See [here](../how_to_guides/user_guide/index.md) for all the available documentation in the User guide.
